<?php

switch ($messaggio) {

case "Visualizza Tabelle":  			$messaggio = "Exibir tabelas"; break;
case "Vedi le prenotazioni":  			$messaggio = "Visualizar as reservas"; break;
case "presenti dal":  				$messaggio = "atuais de"; break;
case "al":  					$messaggio = "a"; break;
case "Senza colori":  				$messaggio = "Sem cores"; break;
case "Con colori":  				$messaggio = "Com cores"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Tabela com reservas anteriores ao"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Tabela com reservas posteriores ao"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabela com todas as reservas"; break;
case "Cognome_cliente":  			$messaggio = "Sobrenome cliente"; break;
case "Data_iniziale":  				$messaggio = "Data inicial"; break;
case "Data_finale":  				$messaggio = "Data final"; break;
case "sett":  					$messaggio = "semana"; break;
case "gio":  					$messaggio = "dia"; break;
case "Tariffa_completa":  			$messaggio = "Tarifa completa"; break;
case "Caparra":  				$messaggio = "Depósito"; break;
case "Pagato":  				$messaggio = "Pago"; break;
case "Da_pagare":  				$messaggio = "A pagar"; break;
case "Pers.":  					$messaggio = "Pess."; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Costo_uni.":  				$messaggio = "Custo único"; break;
case "Costo_sett.":  				$messaggio = "Custo sema."; break;
case "Costo_gio.":  				$messaggio = "Custo diá."; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Dinheiro de reservas canceladas"; break;
case "Trasferito in cassa":  			$messaggio = "Transferido em caixa"; break;
case "RESTO":  					$messaggio = "RESTANTE"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Você tem certeza que deseja apagar a despesa"; break;
case "del valore di":  				$messaggio = "com valor de"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Você tem certeza que deseja apagar a entrada"; break;
case "SI":  					$messaggio = "SIM"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Entrata o spesa":  			$messaggio = "Entrada ou despesa"; break;
case "cacellata":  				$messaggio = "apagada"; break;
case "Costo o spesa già cancellati":  		$messaggio = "A entrada ou despesa já foi apagada"; break;
case "Tutte le spese del":  			$messaggio = "Todas as despesas do"; break;
case "nella cassa principale":  		$messaggio = "na caixa principal"; break;
case "Natura_spesa":  				$messaggio = "Categoría da despesa"; break;
case "Importo":  				$messaggio = "Valor"; break;
case "Inserita_da":  				$messaggio = "Inserido por"; break;
case "Data_di_inserimento":  			$messaggio = "Data da inserção"; break;
case "Cancella":  				$messaggio = "Apagar"; break;
case "Tutte le entrate del":  			$messaggio = "Todas as entradas de"; break;
case "Natura_entrata":  			$messaggio = "Categoría da entrada"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Entrada retirada das reservas"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Inserir novas entradas ou despesas"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "Histórico de entradas e despesas das reservas"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Você tem certeza que deseja apagar o custo adicional"; break;
case "Il costo aggiuntivo":  			$messaggio = "O custo adicional"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "O custo adicional foi alterado entretanto, então não foi apagado"; break;
case "è stato cancellato":  			$messaggio = "foi apagado"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "O speríodos foram acrescentados até o"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Tabela com  períodos e respectivas tarifas do"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Inizio_settimana":  			$messaggio = "Inicio semana"; break;
case "Inizio_giorno":  				$messaggio = "Inicio dia"; break;
case "Fine_settimana":  			$messaggio = "Fim semana"; break;
case "Fine_giorno":  				$messaggio = "Fim dia"; break;
case "Aggiungi periodi":  			$messaggio = "Acrescentar períodos"; break;
case "fino al mese":  				$messaggio = "até o mês"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Tabela com custos adicionais do"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Prezzo":  				$messaggio = "Valor"; break;
case "Da_assegnare":  				$messaggio = "Para atribuir"; break;
case "finale":  				$messaggio = "final"; break;
case "Sempre":  				$messaggio = "Sempre"; break;
case "Su_richiesta":  				$messaggio = "Sobre consulta"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "perguntar por quanto multiplicar"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considerar como camas extra"; break;
case "settimanale":  				$messaggio = "semanal"; break;
case "giornaliero":  				$messaggio = "diário"; break;
case "tutte":  				$messaggio = "todas"; break;
case "tutti":  				$messaggio = "todos"; break;
case "_le":  					$messaggio = " as"; break;
case "_i":  					$messaggio = " os"; break;
case "_settimane":  				$messaggio = " semanas"; break;
case "_giorni":  				$messaggio = " dias"; break;
case "_meno_una":  				$messaggio = " menos uma"; break;
case "con_n°_di_settimane":  			$messaggio = "com nº de semanas"; break;
case "con_n°_di_giorni":  			$messaggio = "com nº de dias"; break;
case "_da_chiedere":  				$messaggio = " sobre consulta"; break;
case "percentuale":  				$messaggio = "percentagem"; break;
case "% arrotondato_a_":  			$messaggio = "% arredondado a "; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Depositos, comissões e taxas do"; break;
case "Arrotondato_a":  				$messaggio = "Arredondado para"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Ir para a página de introdução de preços"; break;
case "chiamati":  				$messaggio = "chamados"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Pesquisar clientes por nome ou e-mail"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabela com todos os clientes"; break;
case "pag. prec.":  				$messaggio = "pág. ante."; break;
case "pag. succ.":  				$messaggio = "próx. pág.."; break;
case "Cognome":  				$messaggio = "Sobrenome"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "Telefono":  				$messaggio = "Telefone"; break;
case "Indirizzo":  				$messaggio = "Endereço"; break;
case "Città":  					$messaggio = "Cidade"; break;
case "Nazione":  				$messaggio = "País"; break;
case "CAP":  					$messaggio = "CEP"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "Data_di_nascita":  			$messaggio = "Data do nascimento"; break;
case "2°telefono":  				$messaggio = "2º telefone"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Você tem certeza que deseja <b>apagar</b> a regra de atribuição 1 pela"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Você tem certeza que deseja <b>apagar</b> a regra de atribuição 2 pela"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Você tem certeza que deseja <b>apagar</b> a regra de atribuição 3 pela"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Você tem certeza que deseja <b>apagar</b> a regra de atribuição 4 pela"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "A regra de atribuição foi apagada"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "A regra de atribuição já era apagada"; break;
case "Tabella con le regole di assegnazione":	$messaggio = "Tabela com as regras de atribuição"; break;
case "del":					$messaggio = "do"; break;
case "Motivazione":  				$messaggio = "Razão"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "Inserisci nuove regole":  		$messaggio = "Inserir novas regras"; break;
case "Il numero inserito esiste già":  		$messaggio = "O número inserido já existe"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Casa":  					$messaggio = "Casa"; break;
case "Piano":  					$messaggio = "Andar"; break;
case "Capienza_massima":  			$messaggio = "Capacidade máxima"; break;
case "Priorità":  				$messaggio = "Prioridade"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "persone":  				$messaggio = "pessoas"; break;
case "s":  					$messaggio = "s"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Mostrar"; break;
case "Non_mostrare":  				$messaggio = "Não mostrar"; break;
case "Regole":  				$messaggio = "Regras"; break;
case "Tariffe abbinate":  			$messaggio = "Tarifas combinadas"; break;
case "pagine":  				$messaggio = "páginas"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "As seguintes alterações serão feitas"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "O dinheiro pago pela reserva"; break;
case "a nome di":  				$messaggio = "em nome de"; break;
case "verranno cambiati da":  			$messaggio = "será alterado de"; break;
case "a":  					$messaggio = "para"; break;
case "saldo":  					$messaggio = "saldo"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "As reservas <b>não foram alteradas</b> porque a tabela de reservas foi alterada entretanto"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "Alterar reservas escolhidas para"; break;
case "cambia":  				$messaggio = "alterar"; break;
case "tutto pagato":  				$messaggio = "tudo pago"; break;
case "caparra pagata":  			$messaggio = "depósito pago"; break;
case "pagato niente":  				$messaggio = "nada pago"; break;
case "pagina":  				$messaggio = "página"; break;
case "di":  					$messaggio = "de"; break;
case "la conferma":  				$messaggio = "a confirmação"; break;
case "La prenotazione":  			$messaggio = "A reserva"; break;
case "verrà confermata":  			$messaggio = "será confirmada"; break;
case "Data di inserimento":  			$messaggio = "Data de inserção"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calcular subtotal das reservas escolhidas"; break;
case "selezionate precedentemente":  		$messaggio = "escolhidas anteriormente"; break;
case "Saldo totale":  				$messaggio = "Saldo total"; break;
case "l'anno":  				$messaggio = "o ano"; break;
case "dal database":  				$messaggio = "do banco de dados"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">ATENÇÃO</b>: se clicar em <b>\"<i>Continuar</i>\"</b>, todos os dados referentes ao ano"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "serão <b>apagados</b>"; break;
case "L'anno":  				$messaggio = "O ano"; break;
case "è stato cancellato dal batabase":  	$messaggio = "foi apagado do banco de dados"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "Não foi possível apagar o ano"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "do banco de dados. Verifique os privilégios na pasta dati"; break;
case "Profilo":  				$messaggio = "Perfil"; break;
case "Cliente":  				$messaggio = "Cliente"; break;
case "cliente":  				$messaggio = "cliente"; break;
case "Utente":  				$messaggio = "Usuário"; break;
case "Periodi_permessi":  			$messaggio = "Períodos concedidos"; break;
case "unico":  					$messaggio = "único"; break;
case "fisso":  					$messaggio = "fixo"; break;
case "percentuale su tariffa":  		$messaggio = "percentagem da tarifa"; break;
case "percentuale su totale":  			$messaggio = "percentagem do total"; break;
case "varia_con_la_prenotazione":  		$messaggio = "variar com a reserva"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "nao variar com a reserva"; break;
case "_meno_l'ultima":  			$messaggio = " menos a última"; break;
case "_meno_l'ultimo":  			$messaggio = " menos o último"; break;
case "_meno_la_prima":  			$messaggio = " menos a primeira"; break;
case "_meno_il_primo":  			$messaggio = " menos o primeiro"; break;
case "giorni":  				$messaggio = "dias"; break;
case "moltiplicare_per_persone":  		$messaggio = "multiplicar por pessoas"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multiplicar por total de pessoas"; break;
case "moltiplicare_per_1":  			$messaggio = "multiplicar por 1"; break;
case "massimo_":  				$messaggio = "maximo "; break;
case "_nella_stessa_settimana":  		$messaggio = " na mesma semana"; break;
case "_nello_stesso_giorno":  			$messaggio = " no mesmo dia"; break;
case "Prenotazione intera in":  		$messaggio = "Reserva inteira em"; break;
case "Parte della prentoazione in":  		$messaggio = "Parte da reserva em"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Apenas semanas da reserva em"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Apenas dias da reserva em"; break;
case " o ":  					$messaggio = " ou "; break;
case " a ":  					$messaggio = " a "; break;
case "_si":  					$messaggio = " sim"; break;
case "_no":  					$messaggio = " nao"; break;
case "_e_":  					$messaggio = " e "; break;
case "associato_a_settimane_specifiche":  	$messaggio = "associado a semanas especificas"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "não associado a semanas especificas"; break;
case "associato_a_giorni_specifici":  		$messaggio = "associado a dias especificos"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "não associado a dias especificos"; break;
case "modifica con prenotazione":  		$messaggio = "modificar com reserva"; break;
case "percentuale su caparra":  		$messaggio = "percentagem do depósito"; break;
case "percentuale su resto caparra":  		$messaggio = "percentagem sobre o restante do depósito"; break;
case "Cancellati":  				$messaggio = "Apagados"; break;
case "clienti":  				$messaggio = "clientes"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Cancelar"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Você tem certeza que deseja <div style=\"display: inline; color: red;\"><b>apagar"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clientes</b></div> que não tem nenhuma reserva ou pagamento associado"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "dados de cartões de crédito</b></div> associado com clientes que não têm nenhuma reserva no futuro e nenhuma reserva sem ser paga"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Apagar clientes sem reservas"; break;
case "Metodo pagamento":  			$messaggio = "Forma de pagamento"; break;
case "Tariffe":  				$messaggio = "Tarifas"; break;
case "del":  					$messaggio = "do"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Modificar todos os campos da tabela"; break;
case "Modifica i campi della tabella":  	$messaggio = "Modificar os campos da tabela"; break;
case "Applica i cambiamenti":  			$messaggio = "Aplicar alterações"; break;
case "documento di tipo":  			$messaggio = "documento do tipo"; break;
case "visualizza":  				$messaggio = "visualizar"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "Visualizar todas as reservas"; break;
case "Numero di persone":  			$messaggio = "Número de pessoas"; break;
case "assegna_se_":  				$messaggio = "atribuir se "; break;
case "più_di_":  				$messaggio = "mais de "; break;
case "meno_di_":  				$messaggio = "menos de "; break;
case "_giorni_da_inizio":  			$messaggio = " dias do início"; break;
case "assegna_con_":  				$messaggio = "atribuir com "; break;
case "_o_più_prenotazioni":  			$messaggio = " ou mais reservas"; break;
case "Modifica i prezzi":  			$messaggio = "Modificar os preços"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "<div style=\"display: inline; color: red;\">Não</div> foi possível inserir alguns preços"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "Os preços foram atualizados"; break;
case "Tutte le prenotazioni":  			$messaggio = "Todas as reservas"; break;
case "Solo arrivi":  				$messaggio = "Apenas as chegadas"; break;
case "Solo partenze":  				$messaggio = "Apenas as saídas"; break;
case "dal":  					$messaggio = "de"; break;
case "Vedi":  					$messaggio = "Ver"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Tabela com todas as chegadas"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Tabela com todas as saídas"; break;
case "prova ad importare i prezzi":  		$messaggio = "tentar importar os preços"; break;
case "giornalmente":  				$messaggio = "diariamente"; break;
case "settimanalmente":  			$messaggio = "semanalmente"; break;
case "Origine":  				$messaggio = "Origem"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modificar as reservas mostradas na tabela em grupo "; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modificar as reservas escolhidas em grupo"; break;
case "Statistiche":  				$messaggio = "Estatística"; break;
case "Anni":  					$messaggio = "Anos"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Números de reservas por mês"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Entradas das reservas por mês"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Entradas progressivas das reservas"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Número de reservas por origem"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Entradas das reservas por origem"; break;
case "Cambia":  				$messaggio = "Alterar"; break;
case "Mesi":  					$messaggio = "Meses"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Entradas por forma de pagamento"; break;
case "Descrizione":  				$messaggio = "Descrição"; break;
case "magazzino":  				$messaggio = "armazém"; break;
case "inventario":  				$messaggio = "inventário"; break;
case "aggiungi":  				$messaggio = "adicionar"; break;
case "Codice":  				$messaggio = "Código"; break;
case "Beni inventario":  			$messaggio = "Bens do inventário"; break;
case "Mancanti":  				$messaggio = "Em falta"; break;
case "bene eliminato":  			$messaggio = "bem apagado"; break;
case "bene aggiunto":  				$messaggio = "bem adicionado"; break;
case "magazzino eliminato":  			$messaggio = "armazém apagado"; break;
case "magazzino aggiunto":  			$messaggio = "armazém adicionado"; break;
case "Inventario importato":  			$messaggio = "Inventário importado"; break;
case "Importa l'invetario":  			$messaggio = "Importar o inventário"; break;
case "dal magazzino":  				$messaggio = "do armazém"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilidade"; break;
case "raggruppa":  				$messaggio = "reagrupar"; break;
case "con email":  				$messaggio = "com e-mail"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "per persona":  				$messaggio = "por pessoa"; break;
case "con meno di":  				$messaggio = "com menos de"; break;
case "dall'inizio":  				$messaggio = "do início"; break;
case "dalla fine":  				$messaggio = "do fim"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Mostrar apenas as tarifas escolhidas"; break;
case "mostra prezzi settimanali":  		$messaggio = "Mostrar preços semanais"; break;
case "mostra prezzi giornalieri":  		$messaggio = "Mostrar preços diários"; break;
case "periodi di":  				$messaggio = "períodos de"; break;
case "Valore":  				$messaggio = "Valor"; break;
case "della tariffa":  				$messaggio = "da tarifa"; break;
case "piano":  					$messaggio = "andar"; break;
case "casa":  					$messaggio = "casa"; break;
case "documento":  				$messaggio = "documento"; break;
case "documenti salvati":  			$messaggio = "documentos salvos"; break;
case "in":  					$messaggio = "em"; break;
case "numero":  				$messaggio = "número"; break;
case "nome file":  				$messaggio = "nome dos arquivos"; break;
case "prenotazioni":  				$messaggio = "reservas"; break;
case "azione":  				$messaggio = "ação"; break;
case "anno":  					$messaggio = "ano"; break;
case "elimina":  				$messaggio = "apagar"; break;
case "fai l'upload del documento numero":  	$messaggio = "carregar o documento número"; break;
case "fai l'upload":  				$messaggio = "carregar"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Você tem certeza que deseja <b class=\"colred\">apagar</b> o documento"; break;
case "cancellato":  				$messaggio = "apagado"; break;
case "inviato":  				$messaggio = "enviado"; break;
case "Commissioni":  				$messaggio = "Comissões"; break;
case "Tasse":  					$messaggio = "Taxas"; break;
case "senza_commissioni":  			$messaggio = "sem comissoes"; break;
case "Documenti_salvati":  			$messaggio = "documentos salvos"; break;
case "TASSE":  					$messaggio = "TAXAS"; break;
case "resto":  					$messaggio = "restante"; break;
case "cancella_periodi":  			$messaggio = "apagar periodos"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Você tem certeza que deseja apagar as comissões do"; break;
case "sulla tariffa":  				$messaggio = "na tarifa"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "As comissões foram apgadas"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "As comissões foram alteradas entretanto, então não foram apagadas"; break;
case "giorno":  				$messaggio = "dia"; break;
case "settimana":  				$messaggio = "semana"; break;
case "costi agg.":  				$messaggio = "custos adic."; break;
case "sconto":  				$messaggio = "desconto"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Número de reservas por nacionalidade do cliente titular"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Entradas de reservas por nacionalidade do cliente titular"; break;
case "Prezzi con":  				$messaggio = "Preços com"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Reservas ano atual"; break;
case "con prenotazioni inserite":  		$messaggio = "com reservas inseridas"; break;
case "fino al":  				$messaggio = "até o"; break;
case "nella cassa chiamata":  			$messaggio = "na caixa chamada"; break;
case "Totale nella cassa principale":  		$messaggio = "Total na caixa principal"; break;
case "Totale nella cassa":  			$messaggio = "Total na caixa"; break;
case "Nuova cassa chiamata":  			$messaggio = "Nova caixa chamada"; break;
case "Crea":  					$messaggio = "Criar"; break;
case "Una cassa chiamata":  			$messaggio = "Uma caixa chamada"; break;
case "è stata creata":  			$messaggio = "foi criada"; break;
case "Cassa chiamata":  			$messaggio = "Caixa chamada"; break;
case "La cassa chiamata":  			$messaggio = "A caixa chamada"; break;
case "è stata cancellata":  			$messaggio = "foi apagada"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Eventuais entradas e despesa presentes na caixa não foram apagadas"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modificar os bens já inseridos"; break;
case "Modifica i beni":  			$messaggio = "Modificar os bens "; break;
case "I beni sono stati modificati":  		$messaggio = "Os bens foram modifacodos"; break;
case "p":  					$messaggio = "pess."; break;
case "e combina":  				$messaggio = "e combinar"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentagem no preço fixo da tarifa"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentagem no preço por pessoa da tarifa"; break;
case "non più di":  				$messaggio = "não mais de"; break;
case "non più del numero di persone":  		$messaggio = "não mais do que o número de pessoas"; break;
case "non più del numero totale di persone":  	$messaggio = "não mais do que o número total de pessoas"; break;
case "meno":  					$messaggio = "menos"; break;
case "aggiungendo":  				$messaggio = "adicionando"; break;
case "più di":  				$messaggio = "mais de"; break;
case "prezzi importati":  			$messaggio = "preços importados"; break;
case "dalla tariffa":  				$messaggio = "da tarifa"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Apagar os dados dos cartões de crédito de reservas passadas"; break;
case "password per le carte di credito":  	$messaggio = "senha para acessar os detalhes dos cartões de crédito"; break;
case "Cancellate":  				$messaggio = "Apagados"; break;
case "carte di credito":  			$messaggio = "cartões de crédito"; break;
case "password errata":  			$messaggio = "senha errada"; break;
case "Creare":  				$messaggio = "Criar"; break;
case "Aggiungi":  				$messaggio = "Adicionar"; break;
case "persona":  				$messaggio = "pessoa"; break;
case "chiusa":  				$messaggio = "fechada"; break;
case "presenti in data":  			$messaggio = "presente na data"; break;
case "comprese partenze":  			$messaggio = "incluindo saídas"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "excluir do total percentual"; break;
case "da varie tariffe":  			$messaggio = "de várias tarifas"; break;
case "senza letti aggiuntivi":  		$messaggio = "sem camas adicionais"; break;
case "Premere per modificare":  		$messaggio = "Clique para modificar"; break;
case "Converti definitivamente in":  		$messaggio = "Definitivamente convertido em"; break;
case "al cambio attuale":  			$messaggio = "na taxa de câmbio atual"; break;
case "Le altre valute presenti nella cassa":  	$messaggio = "As outras moedas presentes no caixa"; break;
case "sono state convertite in":  		$messaggio = "foram convertidos para"; break;
case "Tabella con le prenotazioni cancellate":	$messaggio = "Tabela com reservas canceladas"; break;
case "<b>non importare</b> i prezzi":  		$messaggio = "<b>não importe</b> preços"; break;
case "Attenzione":  				$messaggio = "Atenção"; break;
case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "os períodos adicionados não poderão mais ser eliminados"; break;
case "come tipo di persona":  			$messaggio = "como tipo de pessoa"; break;
case "e applica la % del tipo di persona":  	$messaggio = "e aplique a % do tipo de pessoa"; break;
case "escludendo":  				$messaggio = "excluindo"; break;
case "includendo solo":  			$messaggio = "incluindo apenas"; break;
case "e":  					$messaggio = "e"; break;
case "Superato il massimo numero di anni comparabili":	$messaggio = "Superou o número máximo de anos comparáveis"; break;
case "Numero_predefinito di persone":  		$messaggio = "Número_predefinido de pessoas"; break;
case "Numero_minimo di persone":  		$messaggio = "Número_mínimo de pessoas"; break;
case "Id":  					$messaggio = "Id"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "Prenotazioni cancellate":  		$messaggio = "Reservas canceladas"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Cancellare anche":  			$messaggio = "Delete also"; break;
case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
case "Anche cancellate":  			$messaggio = "Also deleted"; break;
case "Solo cancellate":  			$messaggio = "Only deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
